@@ -12,5 +12,5 @@ golden = golden_ratio = UnitConstant(
     'golden_ratio',
     (1 + _math.sqrt(5)) / 2,
     u_symbol='ϕ',
-    aliases='golden'
+    aliases=['golden']
 )
